@@ -7,16 +7,17 @@
 #'
 #' @param x `auk_ebd` or `auk_sampling` object; reference to file created by 
 #'   [auk_ebd()] or [auk_sampling()].
-#' @param protocol character; "Stationary", "Traveling", "Area", or
-#'   "Incidental". Many protocols exist in the database, however, this function
-#'   only extracts the following protocols. Multiple protocols are
-#'   allowed at the same time:
+#' @param protocol character. Many protocols exist in the database, however, this function
+#'   only extracts the following protocols:
 #'   
 #'   - Stationary
 #'   - Traveling
 #'   - Area
 #'   - Incidental
 #'   - Nocturnal Flight Call Count
+#'   - PROALAS
+#'   
+#'   Multiple protocols are allowed at the same time.
 #' 
 #' @details This function can also work with on an `auk_sampling` object if the 
 #'   user only wishes to filter the sampling event data.
@@ -41,7 +42,8 @@ auk_protocol.auk_ebd <- function(x, protocol) {
   assertthat::assert_that(
     all(protocol %in% c("Stationary", "Traveling", "Area", 
                         "Incidental",
-                        "Nocturnal Flight Call Count"))
+                        "Nocturnal Flight Call Count",
+                        "PROALAS"))
   )
   
   # set filter list
